@@ -2,20 +2,21 @@
  * Worldvisions Weaver Software:
  *   Copyright (C) 1998 Worldvisions Computer Technology, Inc.
  */
-#include "wvudp.h"
+#include "wvstreamlist.h"
 #include "wvlog.h"
+#include "wvudp.h"
 
 int main(int argc, char **argv)
 {
     WvLog err("udptest", WvLog::Error);
-    WvIPPortAddr localaddr(argc > 1 ? argv[1] : "0.0.0.0:4123"),
-		   remaddr(argc > 2 ? argv[2] : "0.0.0.0");
-    WvUDPStream sock(localaddr, WvIPPortAddr());
+    WvIPPortAddr nothing;
+    WvIPPortAddr remaddr(argc > 1 ? argv[1] : "127.0.0.1:19");
+    WvUDPStream sock(nothing, nothing);
     
-    err(WvLog::Info, "Bound to local address %s.\n", localaddr);
+    err(WvLog::Info, "Local address is %s.\n", *sock.local());
     
     wvcon->autoforward(sock);
-    sock.autoforward(*wvcon);
+    sock.autoforward(err);
     
     WvStreamList l;
     l.add_after(l.tail, wvcon, false);
@@ -26,11 +27,14 @@ int main(int argc, char **argv)
 	sock.setdest(remaddr);
 	if (l.select(1000))
 	{
-	    l.callback();
-	    err(WvLog::Info, "    (remote: %s)\n", *sock.src());
+	    if (wvcon->select(0))
+		wvcon->callback();
+	    else if (sock.select(0))
+	    {
+		sock.callback();
+		err(WvLog::Info, "    (remote: %s)\n", *sock.src());
+	    }
 	}
-	else
-	    sock.print("%s\n", localaddr);
     }
     
     if (!wvcon->isok() && wvcon->geterr())
