@@ -3,13 +3,21 @@
  *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
  */
 #include "wvmodem.h"
+#include "wvstreamlist.h"
 #include "wvlog.h"
 #include "strutils.h"
 
-int main()
+int main(int argc, char **argv)
 {
     WvLog log("modemtest"), modemlog("Rx");
-    WvModem modem("/dev/ttyS3", 19200);
+
+    if (argc < 2)
+    {
+	log("usage: modemtest <devname>\n");
+	return 1;
+    }
+    
+    WvModem modem(argv[1], 19200);
     unsigned char buf[1024];
     size_t len;
     bool last_carrier = false, carrier;
@@ -20,8 +28,6 @@ int main()
     
     while (modem.isok() && wvcon->isok())
     {
-	WvStream *s = l.select_one(100);
-	
 	carrier = modem.carrier();
 	if (last_carrier != carrier)
 	{
@@ -29,13 +35,16 @@ int main()
 	    last_carrier = carrier;
 	}
 	
-	if (s==wvcon)
+	if (!l.select(100))
+	    continue;
+	
+	if (wvcon->select(0))
 	{
 	    len = wvcon->read(buf, sizeof(buf));
 	    replace_char(buf, '\n', '\r', len);
 	    modem.write(buf, len);
 	}
-	else if (s==&modem)
+	else if (modem.select(0))
 	{
 	    len = modem.read(buf, sizeof(buf));
 	    modemlog.write(buf, len);
