@@ -25,26 +25,25 @@ public:
     // NOTE: we must NOT use *cloned at this point since the caller may
     //  not have had a chance to initialize it yet!
     WvStreamClone(WvStream **_cloned)
-        { cloned = _cloned; setcallback(default_callback, this); }
+        { cloned = _cloned; }
     virtual ~WvStreamClone();
     
     virtual void close();
     virtual int getfd() const;
     virtual size_t uread(void *buf, size_t size);
     virtual size_t uwrite(const void *buf, size_t size);
-    virtual bool test_set(fd_set &r, fd_set &w, fd_set &x);
     virtual bool isok() const;
     virtual int geterr() const;
     virtual const char *errstr() const;
-    virtual bool select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
-			      bool readable, bool writable, bool isexception);
+    virtual bool select_setup(SelectInfo &si);
+    virtual bool test_set(SelectInfo &si);
     virtual const WvAddr *src() const;
+    virtual void execute();
 
 protected:
     WvStream **cloned;
     WvStream *s() const
         { return cloned ? *cloned : (WvStream*)NULL; }
-    static WvStream::Callback default_callback;
 };
 
 #endif // __WVSTREAMCLONE_H
